@@ -23,11 +23,8 @@ SOFTWARE.
 """
 
 
-
-
-from .__vid__ import Video
-from .__ch__ import Channel
-from .__qry__ import Search
-from .__ext__ import Extras
-from .__plls__ import Playlist
-
+from ._video import Video
+from ._query import Search
+from ._extras import Extras
+from ._channel import Channel
+from ._playlist import Playlist
